//++
//
// ms_centre GUI processing module (GuiModule.cpp)
//
//  2005, Nick Morgalla
// MorSoft / MorSynth
// June 2005
//
// Using SynthEdit SDK V2.180
// Based on examples provided by:
//  2002, Jeff M Soft und Hardware GmbH, All Rights Reserved
//
// Used to centre (zero) a control knob, e.g. a fine or coarse tuning knob
//--

//+
// Includes
//-
#include "guimodule.h"
#include "windows.h"
#include <stdio.h>
#include <assert.h>

//+
// I/O pins
//
// Note, these definitions must match those in the audio processing class (Module.cpp)
//-
#define PN_Pos			0									// Animation Position
#define PN_Value		1									// Output value

//+
// Callback
//-
GuiModule::GuiModule(seGuiCallback seaudioMaster, void *p_resvd1) : SEGUI_base(seaudioMaster, p_resvd1)
{
}

//+
// Destructor
//-
GuiModule::~GuiModule(void)
{
}

//+
// Initialise
//-
void GuiModule::Initialise(bool loaded_from_file)
{
	SEGUI_base::Initialise(loaded_from_file);

	OnValueChangedBack();									// Set initial switch state based on control position
}

//+
// Pin value changed
//-
void GuiModule::OnGuiPinValueChange(SeGuiPin *p_pin)
{
	//+
	// Establish where the change came from
	//-
	int pinID = p_pin->getIndex();

	if  (pinID == PN_Pos)
	{
		OnValueChanged();									// Centre knob
	}
	else
	{
		OnValueChangedBack();								// Set switch based on knob position
	}
}

void GuiModule::OnValueChanged()
{
	//+
	// Check to see if the switch is activated
	//-
	if (getPin(PN_Pos)->getValueFloat() > 0.0f)
	{
		getPin(PN_Value)->setValueFloat(0.0f);				// Centre (zero) the control
	}
	else
	{
		if (getPin(PN_Value)->getValueFloat() == 0.0f)
		{
			getPin(PN_Pos)->setValueFloat(1.0f);			// Keep the switch activated if knob is centered
		}
	}
}

void GuiModule::OnValueChangedBack()
{
	//+
	// Check to see if the control is centered
	//-
	if (getPin(PN_Value)->getValueFloat() == 0.0f)
	{
		getPin(PN_Pos)->setValueFloat(1.0f);				// Keep the switch activated
	}
	else
	{
		getPin(PN_Pos)->setValueFloat(0.0f);				// Release the switch
	}
}
